@@ -25,15 +25,15 @@ enum fnc_diff_flag {
 	FNC_DIFF_IGNORE_ALLWS	= 0x03,
 	FNC_DIFF_SIDEBYSIDE	= 1 << 2,  /* output side-by-side diff */
 	FNC_DIFF_VERBOSE	= 1 << 3,  /* show added/rm'd file content */
-	FNC_DIFF_BRIEF		= 1 << 4,
+	FNC_DIFF_BRIEF		= 1 << 4,  /* no content, just index lines */
 	FNC_DIFF_HTML		= 1 << 5,
-	FNC_DIFF_LINENO		= 1 << 6,  /* output diff with line numbers */
-	FNC_DIFF_NOOPT		= 1 << 7,  /* og. 0x0100 */
-	FNC_DIFF_INVERT		= 1 << 8,  /* og. 0x0200 */
-	FNC_DIFF_NOTTOOBIG	= 1 << 9,  /* og. 0x0800 */
-	FNC_DIFF_STRIP_EOLCR	= 1 << 10, /* og. 0x1000 */
-	FNC_DIFF_ANSI_COLOR	= 1 << 11, /* og. 0x2000 */
-	FNC_DIFF_PROTOTYPE	= 1 << 12  /* show func sig in hunk header */
+	FNC_DIFF_LINENO		= 1 << 6,  /* show file line numbers */
+	FNC_DIFF_NOOPT		= 1 << 8,  /* suppress optimisations (debug) */
+	FNC_DIFF_INVERT		= 1 << 9,
+	FNC_DIFF_PROTOTYPE	= 1 << 10, /* show scope in hunk header */
+	FNC_DIFF_NOTTOOBIG	= 1 << 11, /* don't compute "large" diffs */
+	FNC_DIFF_STRIP_EOLCR	= 1 << 12, /* strip trailing '\r' */
+	FNC_DIFF_ANSI_COLOR	= 1 << 13
 #define FNC_DIFF_CONTEXT_EX	(((uint64_t)0x04) << 32)  /* Allow 0 context */
 #define FNC_DIFF_CONTEXT_MASK	((uint64_t)0x0000ffff)    /* Default context */
 #define FNC_DIFF_WIDTH_MASK	((uint64_t)0x00ff0000)    /* SBS column width */
